Module alloc

Module alloc 

Adapting custom allocators to work with libghostty.

Structs

Allocator
A custom allocator that libghostty uses for its memory allocations.
Bytes
Bytes allocated by libghostty, possibly using a custom allocator.