Allocator

Struct Allocator 

pub struct Allocator<'ctx, Ctx: 'ctx = ()> { /* private fields */ }
A custom allocator that libghostty uses for its memory allocations.

The allocator may depend on some external state Ctx for the duration of lifetime 'ctx. This is useful for adapting external, stateful allocators that may not have a 'static lifetime.

One example of a custom allocator that does have a 'static lifetime is Rust’s own default allocator, which can also be used within libghostty as Allocator::GLOBAL.

Implementations

Source

impl Allocator<'static>

pub const GLOBAL: Self

A custom allocator based on Rust’s built-in global allocator.