FormatterOptions

Struct FormatterOptions 

pub struct FormatterOptions<'t, 's> { /* private fields */ }
Implementations

Source

impl<'t, 's> FormatterOptions<'t, 's>

pub fn new() -> Self

Create a new set of options for creating a terminal formatter.

pub fn with_format(self, value: Format) -> Self

Specify the output format to emit.

pub fn with_unwrap(self, value: bool) -> Self

Specify whether to unwrap soft-wrapped lines.

pub fn with_trim(self, value: bool) -> Self

Specify whether to trim trailing whitespace on non-blank lines.

pub fn with_selection(self, value: &'s Selection<'t>) -> Self

Specify the selection to restrict output to a range.

If a selection is not given, the formatter defaults to formatting the entire screen.

pub fn with_palette(self, value: bool) -> Self

Specify whether to emit the palette using OSC 4 sequences.

pub fn with_modes(self, value: bool) -> Self

Specify terminal modes that differ from their defaults using CSI h/l.

pub fn with_scrolling_region(self, value: bool) -> Self

Specify whether to emit scrolling region state using DECSTBM and DECSLRM sequences.

pub fn with_tabstops(self, value: bool) -> Self

Specify tabstop positions by clearing all tabs and setting each one.

pub fn with_pwd(self, value: bool) -> Self

Specify the present working directory using OSC 7.

pub fn with_keyboard(self, value: bool) -> Self

Specify keyboard modes such as ModifyOtherKeys.

pub fn with_cursor(self, value: bool) -> Self

Specify whether to emit cursor position using CUP (CSI H).

pub fn with_style(self, value: bool) -> Self

Emit current SGR style state based on the cursor’s active style_id.

Emit current hyperlink state using OSC 8 sequences.

pub fn with_protection(self, value: bool) -> Self

Emit character protection mode using DECSCA.

pub fn with_kitty_keyboard(self, value: bool) -> Self

Emit Kitty keyboard protocol state using CSI > u and CSI = sequences.

pub fn with_charsets(self, value: bool) -> Self

Emit character set designations and invocations.