Graphics

Struct Graphics 

pub struct Graphics<'t> { /* private fields */ }
Available on crate feature kitty-graphics only.
Opaque reference to a Kitty graphics image storage.

Obtained via Terminal::kitty_graphics. The reference is borrowed from the terminal with lifetime 't and remains valid until the next mutating terminal call (e.g. Terminal::vt_write or Terminal::reset).

Implementations

Source

impl<'t> Graphics<'t>

pub fn image(&self, id: u32) -> Option<Image<'t>>

Look up a Kitty graphics image by its image ID.

Returns None if no image with the given ID exists.