PlacementIterator

Struct PlacementIterator 

pub struct PlacementIterator<'alloc> { /* private fields */ }
Available on crate feature kitty-graphics only.
Opaque reference to a Kitty graphics placement iterator.

Implementations

Source

impl<'alloc> PlacementIterator<'alloc>

pub fn new() -> Result<Self>

Create a new placement iterator instance.

pub fn new_with_alloc<'ctx: 'alloc>( alloc: &'alloc Allocator<'ctx>, ) -> Result<Self>

Create a new placement iterator instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn update( &mut self, graphics: &Graphics<'_>, ) -> Result<PlacementIteration<'_, 'alloc>>

Update the placement iterator with the given graphics storage, returning a new placement iteration.