Module mouse

Module mouse 

Encoding mouse events into terminal escape sequences.

Supports X10, UTF-8, SGR, urxvt, and SGR-Pixels mouse protocols.

Basic Usage

  1. Create an encoder instance with Encoder::new.
  2. Configure encoder options with the various Encoder::with_* methods or Encoder::set_options_from_terminal.
  3. For each mouse event:

Structs

Encoder
Mouse encoder that converts normalized mouse events into terminal escape sequences.
EncoderSize
Mouse encoder size and geometry context.
Event
Normalized mouse input event containing action, button, modifiers, and surface-space position.
Position
Mouse position in surface-space pixels.

Enums

Action
Mouse event action type.
Button
Mouse event action identity.
Format
Mouse output format.
TrackingMode
Mouse tracking mode.