Event

Struct Event 

pub struct Event<'alloc>(/* private fields */);
Normalized mouse input event containing action, button, modifiers, and surface-space position.

Implementations

Source

impl<'alloc> Event<'alloc>

pub fn new() -> Result<Self>

Create a new mouse event instance.

pub fn new_with_alloc<'ctx: 'alloc, Ctx>( alloc: &'alloc Allocator<'ctx, Ctx>, ) -> Result<Self>

Create a new mouse event instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn set_action(&mut self, action: Action) -> &mut Self

Set the event action.

pub fn action(&self) -> Action

Get the event action.

pub fn set_button(&mut self, button: Option<Button>) -> &mut Self

Set the event button.

pub fn button(&self) -> Option<Button>

Get the event button.

pub fn set_mods(&mut self, mods: Mods) -> &mut Self

Set keyboard modifiers held during the event.

pub fn mods(&self) -> Mods

Get keyboard modifiers held during the event.

pub fn set_position(&mut self, pos: Position) -> &mut Self

Set the event position in surface-space pixels.

pub fn position(&self) -> Position

Get the event position in surface-space pixels.