Command

Struct Command 

pub struct Command<'p, 'alloc> { /* private fields */ }
A parsed OSC (Operating System Command) command.

The command can be queried for its type and associated data.

Implementations

Source

impl Command<'_, '_>

pub fn command_type(&self) -> CommandType

Get the type of an OSC command.

This can be used to determine what kind of command was parsed and what data might be available from it.