Module render

Module render 

Managing render states of the terminal.

Structs

CellIteration
An active iteration over the cells on a given row within the render state.
CellIterator
Opaque handle to a render state cell iterator.
Colors
Render-state color information.
CursorViewport
Cursor viewport position information.
RenderState
Represents the state required to render a visible screen (a viewport) of a terminal instance.
RowIteration
An active iteration over the rows in the render state.
RowIterator
Opaque handle to a render-state row iterator.
Snapshot
A snapshot of the render state after an update.

Enums

CursorVisualStyle
Visual style of the cursor.
Dirty
Dirty state of a render state after update.