CellIterator

Struct CellIterator 

pub struct CellIterator<'alloc>(/* private fields */);
Opaque handle to a render state cell iterator.

The cell iterator must be updated from a row in order to function, as most data is only accessible per iteration.

Implementations

Source

impl<'alloc> CellIterator<'alloc>

pub fn new() -> Result<Self>

Create a new cell iterator instance.

pub fn new_with_alloc<'ctx: 'alloc, Ctx>( alloc: &'alloc Allocator<'ctx, Ctx>, ) -> Result<Self>

Create a new cell iterator instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn update( &mut self, row: &RowIteration<'alloc, '_>, ) -> Result<CellIteration<'alloc, '_>>

Update the cell iterator for a new row iteration, returning a new cell iteration.