RowIteration

Struct RowIteration 

pub struct RowIteration<'alloc, 's> { /* private fields */ }
An active iteration over the rows in the render state.

Row iterations are created by updating row iterators with a snapshot of the render state. The borrow checker statically guarantees that all accesses of the data do not outlive the given snapshot, at the cost of added lifetime annotations.

Implementations

Source

impl RowIteration<'_, '_>

pub fn next(&mut self) -> Option<&Self>

Move a row iteration to the next row.

Returns Some(row) if the iteration moved successfully and row data is available to read at the new position using row.

pub fn dirty(&self) -> Result<bool>

Whether the current row is dirty.

pub fn raw_row(&self) -> Result<Row>

The raw row value.

pub fn set_dirty(&self, dirty: bool) -> Result<()>

Set dirty state for the current row.