RowIterator

Struct RowIterator 

pub struct RowIterator<'alloc>(/* private fields */);
Opaque handle to a render-state row iterator.

The row iterator must be updated from a snapshot of the render state in order to function, as most data is only accessible per iteration.

Implementations

Source

impl<'alloc> RowIterator<'alloc>

pub fn new() -> Result<Self>

Create a new row iterator instance.

pub fn new_with_alloc<'ctx: 'alloc, Ctx>( alloc: &'alloc Allocator<'ctx, Ctx>, ) -> Result<Self>

Create a new cell iterator instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn update( &mut self, snapshot: &Snapshot<'alloc, '_>, ) -> Result<RowIteration<'alloc, '_>>

Update the row iterator for a snapshot of the render state, returning a new row iteration.