Snapshot

Struct Snapshot 

pub struct Snapshot<'alloc, 's>(/* private fields */);
A snapshot of the render state after an update.

This struct exists to guard data accessed from the render state from being accidentally modified after an update. If you find yourself unable to update the render state due to borrow checker errors, make sure to drop the active snapshot (and data that depends on it) before updating.

Implementations

Source

impl Snapshot<'_, '_>

pub fn dirty(&self) -> Result<Dirty>

Get the current dirty state.

pub fn cols(&self) -> Result<u16>

Get the viewport width.

pub fn rows(&self) -> Result<u16>

Get the viewport height.

pub fn cursor_color(&self) -> Result<Option<RgbColor>>

Get the cursor color that may have been explicitly set by the terminal state.

pub fn cursor_visible(&self) -> Result<bool>

Whether the cursor is currently visible based on terminal modes.

pub fn cursor_blinking(&self) -> Result<bool>

Whether the cursor is currently blinking based on terminal modes.

pub fn cursor_password_input(&self) -> Result<bool>

Whether the cursor is at a password input field.

pub fn cursor_visual_style(&self) -> Result<CursorVisualStyle>

Get the visual style of the cursor.

pub fn cursor_viewport(&self) -> Result<Option<CursorViewport>>

Get the relative position of the cursor and other information if it is currently visible within the viewport.

pub fn colors(&self) -> Result<Colors>

Get the current color information from a render state.

pub fn set_dirty(&self, dirty: Dirty) -> Result<()>

Set dirty state.