Module screen

Module screen 

Terminal screen cell and row types.

These types represent the contents of a terminal screen. A Cell is a single grid cell and a Row is a single row. Both are opaque values whose fields are accessed via their methods.

Structs

Cell
Represents a single terminal cell.
GridRef
Resolved reference to a terminal cell position.
Row
Represents a single terminal row.

Enums

CellContentTag
Cell content tag.
CellSemanticContent
Semantic content type of a cell.
CellWide
Cell wide property.
RowSemanticPrompt
Row semantic prompt state.