RowSemanticPrompt

Enum RowSemanticPrompt 

#[repr(u32)]
pub enum RowSemanticPrompt { None = 0, Prompt = 1, Continuation = 2, }
Row semantic prompt state.

Indicates whether any cells in a row are part of a shell prompt, as reported by OSC 133 sequences.

Variants



None = 0

No prompt cells in this row.



Prompt = 1

Prompt cells exist and this is a primary prompt line.



Continuation = 2

Prompt cells exist and this is a continuation line.