Row

Struct Row 

pub struct Row(/* private fields */);
Represents a single terminal row.

The internal layout is opaque and must be queried via its methods. Obtain cell values from terminal query APIs.

Implementations

Source

impl Row

pub fn is_wrapped(self) -> Result<bool>

Whether this row is soft-wrapped.

pub fn is_wrap_continuation(self) -> Result<bool>

Whether this row is a continuation of a soft-wrapped row.

pub fn has_grapheme_cluster(self) -> Result<bool>

Whether any cells in this row have grapheme clusters.

pub fn is_styled(self) -> Result<bool>

Whether any cells in this row have styling (may have false positives).

Whether any cells in this row have hyperlinks (may have false positives).

pub fn semantic_prompt(self) -> Result<RowSemanticPrompt>

The semantic prompt state of this row.

pub fn has_kitty_virtual_placeholder(self) -> Result<bool>

Whether this row contains a Kitty virtual placeholder.

pub fn is_dirty(self) -> Result<bool>

Whether this row is dirty and requires a redraw.