Adjustment

Enum Adjustment 

#[non_exhaustive]
#[repr(u32)]
pub enum Adjustment { Left = 0, Right = 1, Up = 2, Down = 3, Home = 4, End = 5, PageUp = 6, PageDown = 7, BeginningOfLine = 8, EndOfLine = 9, }
Operation used to adjust a selection endpoint.

Adjustment mutates the selection’s logical end endpoint, not whichever endpoint is visually bottom/right. This preserves keyboard and drag behavior for both forward and reversed selections.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Left = 0

Move left to the previous non-empty cell, wrapping upward.



Right = 1

Move right to the next non-empty cell, wrapping downward.



Up = 2

Move up one row at the current column, or to the beginning of the line if already at the top.



Down = 3

Move down to the next non-blank row at the current column, or to the end of the line if none exists.



Home = 4

Move to the top-left cell of the screen.



End = 5

Move to the right edge of the last non-blank row on the screen.



PageUp = 6

Move up by one terminal page height, or to home if that would move past the top.



PageDown = 7

Move down by one terminal page height, or to end if that would move past the bottom.



BeginningOfLine = 8

Move to the left edge of the current line.



EndOfLine = 9

Move to the right edge of the current line.