Order

Enum Order 

#[non_exhaustive]
#[repr(u32)]
pub enum Order { Forward = 0, Reverse = 1, MirroredForward = 2, MirroredReverse = 3, }
Ordering of a selection’s endpoints in terminal coordinates.

Mirrored orders are only produced by rectangular selections whose start and end endpoints are on opposite diagonal corners that are not simple top-left-to-bottom-right or bottom-right-to-top-left orderings.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Forward = 0

Start is before end in top-left to bottom-right order.



Reverse = 1

End is before start in top-left to bottom-right order.



MirroredForward = 2

Rectangular selection from top-right to bottom-left.



MirroredReverse = 3

Rectangular selection from bottom-left to top-right.