pub struct AutoscrollTickEvent<'alloc> { /* private fields */ }Expand description
Opaque handle to reusable input data for selection gesture autoscroll tick operations.
Implementations
Sourceimpl<'alloc> AutoscrollTickEvent<'alloc>
impl<'alloc> AutoscrollTickEvent<'alloc>
Sourcepub fn new_with_alloc<'ctx: 'alloc>(
alloc: &'alloc Allocator<'ctx>,
) -> Result<Self>
pub fn new_with_alloc<'ctx: 'alloc>( alloc: &'alloc Allocator<'ctx>, ) -> Result<Self>
Create a new selection gesture autoscroll tick event instance with a custom allocator.
See the crate-level documentation regarding custom memory management and lifetimes.
Sourcepub fn set_position(&mut self, x: f64, y: f64) -> Result<&mut Self>
pub fn set_position(&mut self, x: f64, y: f64) -> Result<&mut Self>
Set the surface-space pointer position.
Sourcepub fn set_rectangle(&mut self, value: bool) -> Result<&mut Self>
pub fn set_rectangle(&mut self, value: bool) -> Result<&mut Self>
Set the whether this drag should produce a rectangular selection.
Sourcepub fn set_word_boundary_codepoints(
&mut self,
value: &[char],
) -> Result<&mut Self>
pub fn set_word_boundary_codepoints( &mut self, value: &[char], ) -> Result<&mut Self>
Set the word-boundary codepoints.
The codepoints are copied into event-owned storage when set. If unset, operations that need word boundaries use Ghostty’s defaults.