DeepPressEvent

Struct DeepPressEvent 

pub struct DeepPressEvent<'alloc> { /* private fields */ }
Opaque handle to reusable input data for selection gesture deep press operations.

Implementations

Source

impl<'alloc> DeepPressEvent<'alloc>

pub fn new() -> Result<Self>

Create a new selection gesture deep press event instance.

pub fn new_with_alloc<'ctx: 'alloc>( alloc: &'alloc Allocator<'ctx>, ) -> Result<Self>

Create a new selection gesture deep press event instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn set_word_boundary_codepoints( &mut self, value: &[char], ) -> Result<&mut Self>

Set the word-boundary codepoints.

The codepoints are copied into event-owned storage when set. If unset, operations that need word boundaries use Ghostty’s defaults.

pub fn apply<'t>( &mut self, gesture: &mut Gesture<'_>, terminal: &'t Terminal<'_, '_>, ) -> Result<Option<Selection<'t>>>

Apply a selection gesture deep press event and return the resulting selection snapshot.