Gesture

Struct Gesture 

pub struct Gesture<'alloc> { /* private fields */ }
Opaque handle to state for interpreting terminal selection gestures.

The gesture owns only the state required to interpret pointer events. Calls that use a gesture are not concurrency-safe and must be serialized with terminal mutations.

Memory management

When dropped, this type will temporarily leak a small amount of memory belonging to the internal TrackedGridRefs. They will instead be reclaimed when the terminal they belong to is dropped. This memory can be preemptively reclaimed by calling the Gesture::reset method if needed.

Implementations

Source

impl<'alloc> Gesture<'alloc>

pub fn new() -> Result<Self>

Create a new selection gesture instance.

pub fn new_with_alloc<'ctx: 'alloc>( alloc: &'alloc Allocator<'ctx>, ) -> Result<Self>

Create a new selection gesture instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn reset(&mut self, terminal: &Terminal<'_, '_>)

Reset any active selection gesture state.

This cancels the active click sequence and releases any tracked terminal references owned by the gesture without dropping the gesture object.

pub fn click_count(&self, terminal: &Terminal<'_, '_>) -> Result<u8>

Get the current click count. 0 means inactive.

pub fn dragged(&self, terminal: &Terminal<'_, '_>) -> Result<bool>

Whether the current/last left-click gesture has dragged.

pub fn autoscroll(&self, terminal: &Terminal<'_, '_>) -> Result<Autoscroll>

Get the current autoscroll request.

pub fn behavior(&self, terminal: &Terminal<'_, '_>) -> Result<Behavior>

Get the current gesture behavior.

pub fn anchor<'t>( &self, terminal: &'t Terminal<'_, '_>, ) -> Result<Option<GridRef<'t>>>

Get the current left-click anchor.

Returns None if there is no valid active anchor.