pub struct ReleaseEvent<'alloc> { /* private fields */ }Expand description
Opaque handle to reusable input data for selection gesture release operations.
Implementations
Sourceimpl<'alloc> ReleaseEvent<'alloc>
impl<'alloc> ReleaseEvent<'alloc>
Sourcepub fn new_with_alloc<'ctx: 'alloc>(
alloc: &'alloc Allocator<'ctx>,
) -> Result<Self>
pub fn new_with_alloc<'ctx: 'alloc>( alloc: &'alloc Allocator<'ctx>, ) -> Result<Self>
Create a new selection gesture release event instance with a custom allocator.
See the crate-level documentation regarding custom memory management and lifetimes.