pub struct SelectLineOptions<'t, 'ws> { /* private fields */ }Expand description
Options for deriving a line selection from a terminal grid reference.
If with_whitespace is not called,
Ghostty’s default line-trim whitespace codepoints are used.
Implementations
Sourceimpl<'t, 'ws> SelectLineOptions<'t, 'ws>
impl<'t, 'ws> SelectLineOptions<'t, 'ws>
Sourcepub fn new(grid_ref: GridRef<'t>) -> Self
pub fn new(grid_ref: GridRef<'t>) -> Self
Create a new set of options for deriving a line selection, from the given grid reference.
Sourcepub fn with_whitespace(self, value: &'ws [char]) -> Self
pub fn with_whitespace(self, value: &'ws [char]) -> Self
Specify the codepoints to trim from the start and end of the line.
Sourcepub fn with_semantic_prompt_boundary(self, value: bool) -> Self
pub fn with_semantic_prompt_boundary(self, value: bool) -> Self
Specify whether semantic prompt state changes should bound the line selection.