SelectWordBetweenOptions

Struct SelectWordBetweenOptions 

pub struct SelectWordBetweenOptions<'t, 'bc> { /* private fields */ }
Options for deriving the nearest word selection between two grid references.

If with_boundary_codepoints is not called, Ghostty’s default word-boundary codepoints are used.

Implementations

Source

impl<'t, 'bc> SelectWordBetweenOptions<'t, 'bc>

pub fn new(start: GridRef<'t>, end: GridRef<'t>) -> Self

Create a new set of options for deriving the nearest word selection, from the two given grid references.

pub fn with_boundary_codepoints(self, value: &'bc [char]) -> Self

Specify the word-boundary codepoints.