SelectWordOptions

Struct SelectWordOptions 

pub struct SelectWordOptions<'t, 'bc> { /* private fields */ }
Options for deriving a word selection from a terminal grid reference.

If with_boundary_codepoints is not called, Ghostty’s default word-boundary codepoints are used.

Implementations

Source

impl<'t, 'bc> SelectWordOptions<'t, 'bc>

pub fn new(grid_ref: GridRef<'t>) -> Self

Create a new set of options for deriving a word selection, from the given grid reference.

pub fn with_boundary_codepoints(self, value: &'bc [char]) -> Self

Specify the word-boundary codepoints.