pub struct Style {
pub fg_color: StyleColor,
pub bg_color: StyleColor,
pub underline_color: StyleColor,
pub bold: bool,
pub italic: bool,
pub faint: bool,
pub blink: bool,
pub inverse: bool,
pub invisible: bool,
pub strikethrough: bool,
pub overline: bool,
pub underline: Underline,
}Expand description
Terminal cell style attributes.
A style describes the visual attributes of a terminal cell, including foreground, background, and underline colors, as well as flags for bold, italic, underline, and other text decorations.
Fields
fg_color: StyleColorbg_color: StyleColorunderline_color: StyleColorbold: boolitalic: boolfaint: boolblink: boolinverse: boolinvisible: boolstrikethrough: booloverline: boolunderline: UnderlineImplementations