Module terminal

Module terminal 

Types and functions around terminal state management.

Structs

ConformanceLevel
The level of conformance to the behavior of a specific or a family of physical terminal models.
DeviceAttributeFeature
A feature that a terminal can report to support.
DeviceAttributes
Device attributes response data for all three DA levels. Filled by the Terminal::on_device_attributes callback in response to CSI c, CSI > c, or CSI = c queries. The terminal uses whichever sub-struct matches the request type.
DeviceType
The type of terminal device being emulated.
Mode
A terminal mode consisting of its value and its kind (DEC/ANSI).
Options
Terminal initialization options.
PointCoordinate
A coordinate in the terminal grid.
PrimaryDeviceAttributes
Primary device attributes (DA1) response data.
SecondaryDeviceAttributes
Secondary device attributes (DA2) response data.
SizeReportSize
Terminal size information for encoding size reports.
Terminal
Complete terminal emulator state and rendering.
TertiaryDeviceAttributes
Tertiary device attributes (DA3) response data.

Enums

ModeKind
The kind of a terminal mode.
Point
A point in the terminal grid.
ScrollViewport
Scroll viewport behavior.

Traits

BellFn
Callback type for Terminal::on_bell.
ColorSchemeFn
Callback type for Terminal::on_color_scheme.
DeviceAttributesFn
Callback type for Terminal::on_device_attributes.
EnquiryFn
Callback type for Terminal::on_enquiry.
PtyWriteFn
Callback type for Terminal::on_pty_write.
SizeFn
Callback type for Terminal::on_size.
TitleChanged
Callback type for Terminal::on_title_changed.
XtversionFn
Callback type for Terminal::on_xtversion.