pub struct ConformanceLevel(pub u16);Expand description
The level of conformance to the behavior of a specific or a family of physical terminal models.
Tuple Fields
0: u16Implementations
Sourceimpl ConformanceLevel
impl ConformanceLevel
pub const VT100: Self
pub const VT101: Self
pub const VT102: Self
pub const VT125: Self
pub const VT131: Self
pub const VT132: Self
pub const VT220: Self
pub const VT240: Self
pub const VT320: Self
pub const VT340: Self
pub const VT420: Self
pub const VT510: Self
pub const VT520: Self
pub const VT525: Self