pub struct PrimaryDeviceAttributes(/* private fields */);Expand description
Primary device attributes (DA1) response data.
Returned as part of DeviceAttributes in response to a CSI c query.
Implementations
Sourceimpl PrimaryDeviceAttributes
impl PrimaryDeviceAttributes
Sourcepub const fn new(
conformance_level: ConformanceLevel,
features: &[DeviceAttributeFeature],
) -> Self
pub const fn new( conformance_level: ConformanceLevel, features: &[DeviceAttributeFeature], ) -> Self
Construct primary device attributes from a conformance level and an array of device attribute features.
Prefer defining primary device attributes as a const when the feature
list is statically known. That makes the 64-feature limit fail during
compilation instead of panicking at runtime.
Panics
Panics when more than 64 features are given.