libghostty-vt 0.1.0

Safe Rust API for libghostty-vt, the Ghostty terminal emulation library
docs.rs failed to build libghostty-vt-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: libghostty-vt-0.1.1

libghostty-vt

Safe Rust API over libghostty-vt-sys.

Handle types (Terminal, RenderState, KeyEncoder, etc.) are !Send + !Sync by design. Callers should drive all operations from a single thread.