Module alloc
libghostty_
vt
0.2.0
Module alloc
Module Items
Structs
In crate libghostty_
vt
libghostty_vt
Module
alloc
Adapting custom allocators to work with libghostty.
Structs

Allocator
A custom allocator that libghostty uses for its memory allocations.
Bytes
Bytes allocated by libghostty, possibly using a custom allocator.