Format terminal content as plain text, VT sequences, or HTML.
A formatter captures a reference to a terminal and formatting options. It can be used repeatedly to produce output that reflects the current terminal state at the time of each format call.
Structs
- Formatter
- Formatter that formats terminal content.
- Formatter
Options - Options for creating a terminal formatter.
Enums
- Format
- Output format.