pub struct FormatterOptions<'t, 's> { /* private fields */ }Expand description
Options for creating a terminal formatter.
Implementations
Sourceimpl<'t, 's> FormatterOptions<'t, 's>
impl<'t, 's> FormatterOptions<'t, 's>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new set of options for creating a terminal formatter.
Sourcepub fn with_format(self, value: Format) -> Self
pub fn with_format(self, value: Format) -> Self
Specify the output format to emit.
Sourcepub fn with_unwrap(self, value: bool) -> Self
pub fn with_unwrap(self, value: bool) -> Self
Specify whether to unwrap soft-wrapped lines.
Sourcepub fn with_trim(self, value: bool) -> Self
pub fn with_trim(self, value: bool) -> Self
Specify whether to trim trailing whitespace on non-blank lines.
Sourcepub fn with_selection(self, value: &'s Selection<'t>) -> Self
pub fn with_selection(self, value: &'s Selection<'t>) -> Self
Specify the selection to restrict output to a range.
If a selection is not given, the formatter defaults to formatting the entire screen.
Sourcepub fn with_palette(self, value: bool) -> Self
pub fn with_palette(self, value: bool) -> Self
Specify whether to emit the palette using OSC 4 sequences.
Sourcepub fn with_modes(self, value: bool) -> Self
pub fn with_modes(self, value: bool) -> Self
Specify terminal modes that differ from their defaults using CSI h/l.
Sourcepub fn with_scrolling_region(self, value: bool) -> Self
pub fn with_scrolling_region(self, value: bool) -> Self
Specify whether to emit scrolling region state using DECSTBM and DECSLRM sequences.
Sourcepub fn with_tabstops(self, value: bool) -> Self
pub fn with_tabstops(self, value: bool) -> Self
Specify tabstop positions by clearing all tabs and setting each one.
Sourcepub fn with_keyboard(self, value: bool) -> Self
pub fn with_keyboard(self, value: bool) -> Self
Specify keyboard modes such as ModifyOtherKeys.
Sourcepub fn with_cursor(self, value: bool) -> Self
pub fn with_cursor(self, value: bool) -> Self
Specify whether to emit cursor position using CUP (CSI H).
Sourcepub fn with_style(self, value: bool) -> Self
pub fn with_style(self, value: bool) -> Self
Emit current SGR style state based on the cursor’s active style_id.
Sourcepub fn with_hyperlink(self, value: bool) -> Self
pub fn with_hyperlink(self, value: bool) -> Self
Emit current hyperlink state using OSC 8 sequences.
Sourcepub fn with_protection(self, value: bool) -> Self
pub fn with_protection(self, value: bool) -> Self
Emit character protection mode using DECSCA.
Sourcepub fn with_kitty_keyboard(self, value: bool) -> Self
pub fn with_kitty_keyboard(self, value: bool) -> Self
Emit Kitty keyboard protocol state using CSI > u and CSI = sequences.
Sourcepub fn with_charsets(self, value: bool) -> Self
pub fn with_charsets(self, value: bool) -> Self
Emit character set designations and invocations.