Event

Struct Event 

pub struct Event<'alloc> { /* private fields */ }
Keyboard input event containing information about the physical key pressed, modifiers, and generated text.

Implementations

Source

impl<'alloc> Event<'alloc>

pub fn new() -> Result<Self>

Create a new key event instance.

pub fn new_with_alloc<'ctx: 'alloc, Ctx>( alloc: &'alloc Allocator<'ctx, Ctx>, ) -> Result<Self>

Create a new key event instance with a custom allocator.

See the crate-level documentation regarding custom memory management and lifetimes.

pub fn set_action(&mut self, action: Action) -> &mut Self

Set the key action (press, release, repeat).

pub fn action(&self) -> Action

Get the key action (press, release, repeat).

pub fn set_key(&mut self, key: Key) -> &mut Self

Set the physical key code.

pub fn key(&self) -> Key

Get the physical key code.

pub fn set_mods(&mut self, mods: Mods) -> &mut Self

Set the modifier keys bitmask.

pub fn mods(&self) -> Mods

Get the modifier keys bitmask.

pub fn set_consumed_mods(&mut self, mods: Mods) -> &mut Self

Set the consumed modifiers bitmask.

pub fn consumed_mods(&self) -> Mods

Get the consumed modifiers bitmask.

pub fn set_composing(&mut self, composing: bool) -> &mut Self

Set whether the key event is part of a composition sequence.

pub fn is_composing(&self) -> bool

Get whether the key event is part of a composition sequence.

pub fn set_utf8<S: Into<String>>(&mut self, text: Option<S>) -> &mut Self

Set the UTF-8 text generated by the key event.

The event makes an internal copy of the text since the C API may reuse it without any rigid lifetime guarantees.

pub fn utf8(&mut self) -> Option<&str>

Get the UTF-8 text generated by the key event.

pub fn set_unshifted_codepoint(&mut self, codepoint: char) -> &mut Self

Set the unshifted Unicode codepoint.

pub fn unshifted_codepoint(&self) -> char

Get the unshifted Unicode codepoint.