pub struct DecodedImage<'alloc> {
pub width: u32,
pub height: u32,
pub data: Bytes<'alloc>,
}Available on crate feature
kitty-graphics only.Expand description
Result of decoding an image.
The data buffer must be allocated through the allocator provided to the
decode callback. The library takes ownership and will free it with the
same allocator.
Fields
width: u32Image width in pixels.
height: u32Image height in pixels.
data: Bytes<'alloc>Byte buffer containing the decoded RGBA pixel data.