pub struct PlacementIterator<'alloc> { /* private fields */ }Available on crate feature
kitty-graphics only.Expand description
Opaque reference to a Kitty graphics placement iterator.
Implementations
Sourceimpl<'alloc> PlacementIterator<'alloc>
impl<'alloc> PlacementIterator<'alloc>
Sourcepub fn new_with_alloc<'ctx: 'alloc>(
alloc: &'alloc Allocator<'ctx>,
) -> Result<Self>
pub fn new_with_alloc<'ctx: 'alloc>( alloc: &'alloc Allocator<'ctx>, ) -> Result<Self>
Create a new placement iterator instance with a custom allocator.
See the crate-level documentation regarding custom memory management and lifetimes.
Sourcepub fn update(
&mut self,
graphics: &Graphics<'_>,
) -> Result<PlacementIteration<'_, 'alloc>>
pub fn update( &mut self, graphics: &Graphics<'_>, ) -> Result<PlacementIteration<'_, 'alloc>>
Update the placement iterator with the given graphics storage, returning a new placement iteration.