pub struct Command<'p, 'alloc> { /* private fields */ }Expand description
A parsed OSC (Operating System Command) command.
The command can be queried for its type and associated data.
Implementations
Sourceimpl Command<'_, '_>
impl Command<'_, '_>
Sourcepub fn command_type(&self) -> CommandType
pub fn command_type(&self) -> CommandType
Get the type of an OSC command.
This can be used to determine what kind of command was parsed and what data might be available from it.