Managing render states of the terminal.
Structs
- Cell
Iteration - An active iteration over the cells on a given row within the render state.
- Cell
Iterator - Opaque handle to a render state cell iterator.
- Colors
- Render-state color information.
- Cursor
Viewport - Cursor viewport position information.
- Render
State - Represents the state required to render a visible screen (a viewport) of a terminal instance.
- RowIteration
- An active iteration over the rows in the render state.
- RowIterator
- Opaque handle to a render-state row iterator.
- Snapshot
- A snapshot of the render state after an update.
Enums
- Cursor
Visual Style - Visual style of the cursor.
- Dirty
- Dirty state of a render state after update.