pub struct CellIterator<'alloc>(/* private fields */);Expand description
Implementations
Sourceimpl<'alloc> CellIterator<'alloc>
impl<'alloc> CellIterator<'alloc>
Sourcepub fn new_with_alloc<'ctx: 'alloc, Ctx>(
alloc: &'alloc Allocator<'ctx, Ctx>,
) -> Result<Self>
pub fn new_with_alloc<'ctx: 'alloc, Ctx>( alloc: &'alloc Allocator<'ctx, Ctx>, ) -> Result<Self>
Create a new cell iterator instance with a custom allocator.
See the crate-level documentation regarding custom memory management and lifetimes.
Sourcepub fn update(
&mut self,
row: &RowIteration<'alloc, '_>,
) -> Result<CellIteration<'alloc, '_>>
pub fn update( &mut self, row: &RowIteration<'alloc, '_>, ) -> Result<CellIteration<'alloc, '_>>
Update the cell iterator for a new row iteration, returning a new cell iteration.