pub struct RowIteration<'alloc, 's> { /* private fields */ }Expand description
An active iteration over the rows in the render state.
Row iterations are created by updating row iterators with a snapshot of the render state. The borrow checker statically guarantees that all accesses of the data do not outlive the given snapshot, at the cost of added lifetime annotations.
Implementations