pub struct RowIterator<'alloc>(/* private fields */);Expand description
Implementations
Sourceimpl<'alloc> RowIterator<'alloc>
impl<'alloc> RowIterator<'alloc>
Sourcepub fn new_with_alloc<'ctx: 'alloc, Ctx>(
alloc: &'alloc Allocator<'ctx, Ctx>,
) -> Result<Self>
pub fn new_with_alloc<'ctx: 'alloc, Ctx>( alloc: &'alloc Allocator<'ctx, Ctx>, ) -> Result<Self>
Create a new cell iterator instance with a custom allocator.
See the crate-level documentation regarding custom memory management and lifetimes.
Sourcepub fn update(
&mut self,
snapshot: &Snapshot<'alloc, '_>,
) -> Result<RowIteration<'alloc, '_>>
pub fn update( &mut self, snapshot: &Snapshot<'alloc, '_>, ) -> Result<RowIteration<'alloc, '_>>
Update the row iterator for a snapshot of the render state, returning a new row iteration.