pub struct Cell(/* private fields */);Expand description
Represents a single terminal cell.
The internal layout is opaque and must be queried via its methods. Obtain cell values from terminal query APIs.
Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn content_tag(self) -> Result<CellContentTag>
pub fn content_tag(self) -> Result<CellContentTag>
The content tag describing what kind of content is in the cell.
Sourcepub fn has_styling(self) -> Result<bool>
pub fn has_styling(self) -> Result<bool>
Whether the cell has non-default styling.
Sourcepub fn has_hyperlink(self) -> Result<bool>
pub fn has_hyperlink(self) -> Result<bool>
Whether the cell has a hyperlink.
Sourcepub fn is_protected(self) -> Result<bool>
pub fn is_protected(self) -> Result<bool>
Whether the cell is protected.
Sourcepub fn semantic_content(self) -> Result<CellSemanticContent>
pub fn semantic_content(self) -> Result<CellSemanticContent>
The semantic content type of the cell (from OSC 133).
Sourcepub fn bg_color_palette(self) -> Result<PaletteIndex>
pub fn bg_color_palette(self) -> Result<PaletteIndex>
The palette index for the cell’s background color.
Only valid when Cell::content_tag is CellContentTag::BgColorPalette.
Sourcepub fn bg_color_rgb(self) -> Result<RgbColor>
pub fn bg_color_rgb(self) -> Result<RgbColor>
The RGB color value for the cell’s background color.
Only valid when Cell::content_tag is CellContentTag::BgColorRgb.