pub struct Row(/* private fields */);Expand description
Represents a single terminal row.
The internal layout is opaque and must be queried via its methods. Obtain cell values from terminal query APIs.
Implementations
Sourceimpl Row
impl Row
Sourcepub fn is_wrapped(self) -> Result<bool>
pub fn is_wrapped(self) -> Result<bool>
Whether this row is soft-wrapped.
Sourcepub fn is_wrap_continuation(self) -> Result<bool>
pub fn is_wrap_continuation(self) -> Result<bool>
Whether this row is a continuation of a soft-wrapped row.
Sourcepub fn has_grapheme_cluster(self) -> Result<bool>
pub fn has_grapheme_cluster(self) -> Result<bool>
Whether any cells in this row have grapheme clusters.
Sourcepub fn is_styled(self) -> Result<bool>
pub fn is_styled(self) -> Result<bool>
Whether any cells in this row have styling (may have false positives).
Sourcepub fn has_hyperlink(self) -> Result<bool>
pub fn has_hyperlink(self) -> Result<bool>
Whether any cells in this row have hyperlinks (may have false positives).
Sourcepub fn semantic_prompt(self) -> Result<RowSemanticPrompt>
pub fn semantic_prompt(self) -> Result<RowSemanticPrompt>
The semantic prompt state of this row.
Sourcepub fn has_kitty_virtual_placeholder(self) -> Result<bool>
pub fn has_kitty_virtual_placeholder(self) -> Result<bool>
Whether this row contains a Kitty virtual placeholder.