pub struct SelectWordBetweenOptions<'t, 'bc> { /* private fields */ }Expand description
Options for deriving the nearest word selection between two grid references.
If with_boundary_codepoints
is not called, Ghostty’s default word-boundary codepoints are used.
Implementations
Sourceimpl<'t, 'bc> SelectWordBetweenOptions<'t, 'bc>
impl<'t, 'bc> SelectWordBetweenOptions<'t, 'bc>
Sourcepub fn new(start: GridRef<'t>, end: GridRef<'t>) -> Self
pub fn new(start: GridRef<'t>, end: GridRef<'t>) -> Self
Create a new set of options for deriving the nearest word selection, from the two given grid references.
Sourcepub fn with_boundary_codepoints(self, value: &'bc [char]) -> Self
pub fn with_boundary_codepoints(self, value: &'bc [char]) -> Self
Specify the word-boundary codepoints.