pub struct SelectWordOptions<'t, 'bc> { /* private fields */ }Expand description
Options for deriving a word selection from a terminal grid reference.
If with_boundary_codepoints
is not called, Ghostty’s default word-boundary codepoints are used.
Implementations
Sourceimpl<'t, 'bc> SelectWordOptions<'t, 'bc>
impl<'t, 'bc> SelectWordOptions<'t, 'bc>
Sourcepub fn new(grid_ref: GridRef<'t>) -> Self
pub fn new(grid_ref: GridRef<'t>) -> Self
Create a new set of options for deriving a word selection, from the given grid reference.
Sourcepub fn with_boundary_codepoints(self, value: &'bc [char]) -> Self
pub fn with_boundary_codepoints(self, value: &'bc [char]) -> Self
Specify the word-boundary codepoints.