Types and functions around terminal state management.
Structs
- Conformance
Level - The level of conformance to the behavior of a specific or a family of physical terminal models.
- Device
Attribute Feature - A feature that a terminal can report to support.
- Device
Attributes - Device attributes response data for all three DA levels.
Filled by the
Terminal::on_device_attributescallback in response to CSI c, CSI > c, or CSI = c queries. The terminal uses whichever sub-struct matches the request type. - Device
Type - The type of terminal device being emulated.
- Mode
- A terminal mode consisting of its value and its kind (DEC/ANSI).
- Options
- Terminal initialization options.
- Point
Coordinate - A coordinate in the terminal grid.
- Primary
Device Attributes - Primary device attributes (DA1) response data.
- Secondary
Device Attributes - Secondary device attributes (DA2) response data.
- Size
Report Size - Terminal size information for encoding size reports.
- Terminal
- Complete terminal emulator state and rendering.
- Tertiary
Device Attributes - Tertiary device attributes (DA3) response data.
Enums
- Mode
Kind - The kind of a terminal mode.
- Point
- A point in the terminal grid.
- Scroll
Viewport - Scroll viewport behavior.
Traits
- BellFn
- Callback type for
Terminal::on_bell. - Color
Scheme Fn - Callback type for
Terminal::on_color_scheme. - Device
Attributes Fn - Callback type for
Terminal::on_device_attributes. - Enquiry
Fn - Callback type for
Terminal::on_enquiry. - PtyWrite
Fn - Callback type for
Terminal::on_pty_write. - SizeFn
- Callback type for
Terminal::on_size. - Title
Changed - Callback type for
Terminal::on_title_changed. - Xtversion
Fn - Callback type for
Terminal::on_xtversion.