Mode

Struct Mode 

pub struct Mode(pub Mode);
A terminal mode consisting of its value and its kind (DEC/ANSI).

Tuple Fields

0: Mode

Implementations

Source

impl Mode

pub const KAM: Self

pub const INSERT: Self

pub const SRM: Self

pub const LINEFEED: Self

pub const DECCKM: Self

pub const _132_COLUMN: Self

pub const SLOW_SCROLL: Self

pub const REVERSE_COLORS: Self

pub const ORIGIN: Self

pub const WRAPAROUND: Self

pub const AUTOREPEAT: Self

pub const X10_MOUSE: Self

pub const CURSOR_BLINKING: Self

pub const CURSOR_VISIBLE: Self

pub const ENABLE_MODE3: Self

pub const REVERSE_WRAP: Self

pub const ALT_SCREEN_LEGACY: Self

pub const KEYPAD_KEYS: Self

pub const LEFT_RIGHT_MARGIN: Self

pub const NORMAL_MOUSE: Self

pub const BUTTON_MOUSE: Self

pub const ANY_MOUSE: Self

pub const FOCUS_EVENT: Self

pub const UTF8_MOUSE: Self

pub const SGR_MOUSE: Self

pub const ALT_SCROLL: Self

pub const URXVT_MOUSE: Self

pub const SGR_PIXELS_MOUSE: Self

pub const NUMLOCK_KEYPAD: Self

pub const ALT_ESC_PREFIX: Self

pub const ALT_SENDS_ESC: Self

pub const REVERSE_WRAP_EXT: Self

pub const ALT_SCREEN: Self

pub const SAVE_CURSOR: Self

pub const ALT_SCREEN_SAVE: Self

pub const BRACKETED_PASTE: Self

pub const SYNC_OUTPUT: Self

pub const GRAPHEME_CLUSTER: Self

pub const COLOR_SCHEME_REPORT: Self

pub const IN_BAND_RESIZE: Self

pub const fn new(v: u16, kind: ModeKind) -> Self

Create a new mode from its numeric value and its kind.

pub const fn value(self) -> u16

The numeric value of the mode.

pub const fn kind(self) -> ModeKind

The kind of the mode (DEC/ANSI).